//Bookmark 
var Bookmark = {

	newlyBookmarkId : null,//新加入的书签ID
	standby : null,
	
	/**
		@description: 分析所携带的书签信息，根据type类型，执行不同的收藏命令
		@message:
			type:ADD_PAGE,ADD_LINK,ADD_TEXT,ADD_IMAGE_LINK,[ADD_IMAGE_STREAM,ADD_VIDEO_LINK...]
			data: bookmark url,title,text string...
			userId: userId or null
		@callback: function for callback
	*/
	addBookmark: function(message , callback){
		
		switch(message.type){
			case "ADD_PAGE":
				this.addPage(message.userId,message.data,callback);
				break;
			case "ADD_TEXT":
				this.addSelectionText(message.userId,message.data,callback);
				break;
			case "ADD_LINK":
				this.addLink(message.userId,message.data,callback);
				break;
			case "ADD_IMAGE_LINK":
				this.addImage(message.userId,message.data,callback);
				break;
		}
	},
	
	/**
		@description: add page as bookmark
		@userId: user id
		@data: bookmark info
		@callback: function for callback
	*/
	addPage : function(userId, data, callback){
		var _this = this;
		
		var options = {
			url:API_ADD_BOOKMARK,
			type:'POST',
			data:{
				userId:userId,
				channel:CHANNEL_ID,
				url:data.url,
				title:data.title
			},
			success:function(res){
				callback(res)
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->addPage: ", jqxhr);
				callback(null)
			}
		}
		commonAjax(options);
	},
	addLink : function(userId, data, callback){
		//console.log("Bookmark adding context link:",data);
		var _this = this;
	
		var options = {
			url:API_ADD_BOOKMARK,
			type:'POST',
			data:{
				userId:userId,
				channel:CHANNEL_ID,
				url:data.url
			},
			success:function(res){
				callback(res)
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->addLink: " ,jqxhr);
				callback(null)
			}
		}
		commonAjax(options);
	},
	addSelectionText : function(userId, data, callback){
		//console.log("Bookmark adding context selection:",data);
		
		var _this = this;
	
		var options = {
			url:API_ADD_BOOKMARK,
			type:'POST',
			data:{
				userId:userId,
				channel:CHANNEL_ID,
				url:data.url,
				text:data.text
			},
			success:function(res){
				callback(res)
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->addSelectionText: " ,jqxhr);
				callback(null)
			}
		}
		commonAjax(options);
	},
	addImage : function(userId, data, callback){
		//console.log("Bookmark adding context image:",data);
		var _this = this;
	
		var options = {
			url:API_ADD_BOOKMARK,
			type:'POST',
			data:{
				userId:userId,
				channel:CHANNEL_ID,
				url:data.url,
				title : data.title,
				fromUrl:data.context_url
			},
			success:function(res){
				callback(res)
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->addImage: ",jqxhr);
				callback(null)
			}
		}
		commonAjax(options);
	},
	
	updateBookmarkCategory : function(category_ids,userInfo,callback){
		
		var _this = this;
		//console.log("updateBookmarkCategory,newlyBookmarkId:",_this.newlyBookmarkId)
		if(_this.newlyBookmarkId == null){
			if(callback) callback(null);
			return false;
		}
		var data = {
			markId : _this.newlyBookmarkId,
			category : category_ids,
			categoryUpdatetime:new Date().getTime()
		};
		var data_str = JSON.stringify([data]);
		
		var options = {
			url:API_UPDATE_BOOKMARK,
			data:{
				userId : userInfo.id,
				data : data_str
				
			},
			success:function(res){
				
				if(res.code == 200){
					//_this.setCategorysData(res.data);
					if(callback) callback(res.data);//res.data == null
				}
				
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->updateBookmarkCategory: ",jqxhr);
				callback(null)
			}
		};
		
		commonAjax(options)
	},
	deleteCurrentBookmark : function(userInfo,callback){
		var _this = this;
		//invalid newlyBookmarkId
		if(this.newlyBookmarkId == null){
			if(callback) callback(null);
			return false;
		}
		
		var data = {
			markId : this.newlyBookmarkId,
			deleted: 1,
			deletedUpdatetime:new Date().getTime()
		};
		var data_str = JSON.stringify([data]);
		
		var options = {
			url:API_UPDATE_BOOKMARK,
			data:{
				userId : userInfo.id,
				data : data_str
			},
			success:function(res){
				_this.newlyBookmarkId = null;
				if(res.code == 200){
					if(callback) callback(true);//res.data == null
				}else{
					if(callback) callback(null);
				}
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->deleteCurrentBookmark: ",jqxhr);
				callback(null)
			}
		};
		commonAjax(options)

	},
	switchCurrentBookmarkPrivate : function(private_status,userInfo,callback){
		if(this.newlyBookmarkId == null){
			if(callback) callback(null);
			return false;
		}
		
		var data = {
			markId : this.newlyBookmarkId,
			privated : private_status,
			privatedUpdatetime : new Date().getTime()
		};
		var data_str = JSON.stringify([data]);
		
		var options = {
			url:API_UPDATE_BOOKMARK,
			data:{
				userId : userInfo.id,
				data : data_str
			},
			success:function(res){
				
				if(res.code == 200){
					if(callback) callback(true);//res.data == null
				}else{
					if(callback) callback(null);
				}
			},
			error: function(jqxhr,textStatus,errorThrown){
				console.log("Bookmark->switchCurrentBookmarkPrivate: ",jqxhr);
				callback(null)
			}
		};
		commonAjax(options)
	}
}
